Index: trunk/ippTools/src/pxtools.c
===================================================================
--- trunk/ippTools/src/pxtools.c	(revision 22751)
+++ trunk/ippTools/src/pxtools.c	(revision 23123)
@@ -36,13 +36,16 @@
     if (!strcmp(state, "wait")) return true;
     if (!strcmp(state, "goto_cleaned")) return true;
+    if (!strcmp(state, "error_cleaned")) return true;
     if (!strcmp(state, "goto_scrubbed")) return true;
+    if (!strcmp(state, "error_scrubbed")) return true;
     if (!strcmp(state, "cleaned")) return true;
     if (!strcmp(state, "update")) return true;
     if (!strcmp(state, "purged")) return true;
     if (!strcmp(state, "goto_purged")) return true;
+    if (!strcmp(state, "error_purged")) return true;
 
     return false;
 }
 
 // goto_scrubbed is similar to cleaned, but allows files to be removed even if the config
 // files is missing
@@ -36,13 +36,16 @@
 }
 
-// goto_scrubbed is similar to cleaned, but allows files to be removed even if the config
-// files is missing
+// 'scrubbed' is a virtual state equivalent to cleaned, but allows files to be removed
+// even if the config files is missing

